@@ -1,8 +1,9 @@
 pub use crate::bump::Bump;
-pub use crate::changelog::Changelog;
+pub use crate::changelog::{AsChangelogFmt, Changelog};
 pub use crate::changeset::Changeset;
 pub use crate::changesets::Changesets;
 pub use crate::error::{ChangesetParseError, ExplorerError, VersionParseError};
+pub use crate::package::{AsPackageGraph, Package, PackageGraph};
 pub use crate::package_manager::PackageManager;
 pub use crate::semantic::Semantic;
-pub use crate::version::{Version, Versioned};
+pub use crate::version::{Version, VersionValue, Versioned};
